from django.db import models

# products/models.py
from django.db import models


class ReusableAutoField(models.PositiveIntegerField):
    """A django auto field that can reuse deleted primary keys"""
    
    def get_next_available_id(self, model_cls, using=None):
        """
        Returns the next available id for the given model class.
        """
        all_ids = set(range(1, model_cls._default_manager.count()+1))
        used_ids = set(model_cls._default_manager.all().values_list('pk', flat=True))
        available_ids = all_ids - used_ids

        if available_ids:
            return min(available_ids)

        if used_ids:
            return max(used_ids) + 1

        return 1

    def get_default(self):
        return self.get_next_available_id(self.model)


class Peg(models.Model):
    """Represents a person getting pegged"""

    peg_number = ReusableAutoField(primary_key=True, default=ReusableAutoField.get_default, editable=False)

    def __str__(self):
        return f"{self.peg_number}"


def get_next_available_peg_id():
    queryset = Peg.__class__._default_manager.all()
    try:
        last_id = queryset.order_by("-pk")[0].pk
    except IndexError:
        last_id = 0
    return last_id + 1


#class Scoreboard(models.Model):
#    class Status(models.IntegerChoices):
#        ACTIVE = 1, "Active"
#        INACTIVE = 2, "Inactive"
#        ARCHIVED = 3, "Archived"
#
#    name = models.CharField(max_length=255)
#    category = models.CharField(max_length=255)
#    price = models.DecimalField(max_digits=10, decimal_places=2)
#    cost = models.DecimalField(max_digits=10, decimal_places=2)
#    status = models.PositiveSmallIntegerField(choices=Status.choices)
#
#    def __str__(self):
#        return self.name